@@ -2,7 +2,7 @@ require File.expand_path(File.dirname(__FILE__)+"/spec_helper.rb")
 describe Rubyvis::Layout::Pack do
   include Rubyvis::LayoutSpec
   it "should have correct properties" do
-    props=[:antialias, :bottom, :canvas, :cursor, :data, :events, :fill_style, :height, :id, :left, :line_width, :links,  :nodes,  :order, :overflow, :reverse, :right, :spacing, :stroke_style, :title, :top, :transform, :visible, :width].inject({}) {|ac, v| ac[v]=true; ac}
+    props=[:antialias, :bottom, :canvas, :cursor, :data, :events, :fill_style, :height, :id, :left, :line_width, :links,  :nodes,  :order, :overflow, :reverse, :right, :spacing, :stroke_style, :title, :top, :transform, :visible, :view_box, :width].inject({}) {|ac, v| ac[v]=true; ac}
     Rubyvis::Layout::Pack.properties.should==props 
   end
   describe "rendered" do
@@ -41,7 +41,7 @@ describe Rubyvis::Layout::Pack do
     it "should render equal nodes (circles)" do
       pv_rects=@pv_svg.xpath("//circle")
       @rv_svg.xpath("//xmlns:circle").each_with_index {|rv_rect,i|
-        rv_rect.should have_same_position pv_rects[i]
+        expect(rv_rect).to have_same_position pv_rects[i]
       }
       
     end
