@@ -2,11 +2,11 @@ require File.expand_path(File.dirname(__FILE__)+"/spec_helper.rb")
 describe Rubyvis::Layout::Partition do
   include Rubyvis::LayoutSpec
   it "subclass Fill should have correct properties" do
-    props=[:antialias, :bottom, :canvas, :cursor, :data, :events, :fill_style, :height, :id, :inner_radius, :left, :line_width, :links,  :nodes,  :order, :orient, :outer_radius, :overflow, :reverse, :right, :stroke_style, :title, :top, :transform, :visible, :width].inject({}) {|ac, v| ac[v]=true; ac}
-    Rubyvis::Layout::Partition::Fill.properties.should==props 
+    props=[:antialias, :bottom, :canvas, :cursor, :data, :events, :fill_style, :height, :id, :inner_radius, :left, :line_width, :links,  :nodes,  :order, :orient, :outer_radius, :overflow, :reverse, :right, :stroke_style, :title, :top, :transform, :view_box, :visible, :width].inject({}) {|ac, v| ac[v]=true; ac}
+    expect(Rubyvis::Layout::Partition::Fill.properties).to eq(props) 
   end
   it "should be called using Rubyvis.Layout.Partition" do
-    Rubyvis.Layout.Partition.should eql Rubyvis::Layout::Partition
+    expect(Rubyvis.Layout.Partition).to eql Rubyvis::Layout::Partition
   end  
   it "should render correctly 'partition_fill' custom test" do
     color=pv.Colors.category19
@@ -39,7 +39,7 @@ left(10)
     
     @vis.render
     @pv_out=fixture_svg_read("layout_partition_fill.svg")
-    @vis.to_svg.should have_same_svg_elements(@pv_out)
+    expect(@vis.to_svg).to have_same_svg_elements(@pv_out)
     end
   
 end
