@@ -2,19 +2,19 @@ require File.expand_path(File.dirname(__FILE__)+"/spec_helper.rb")
 describe Rubyvis::Mark do
   it "should have correct properties" do
     props=[:antialias, :bottom, :cursor, :data, :events, :id, :left, :reverse, :right, :title, :top, :visible].inject({}) {|ac, v| ac[v]=true; ac}
-    Rubyvis::Mark.properties.should==props
+    expect(Rubyvis::Mark.properties).to eq(props)
   end
   it "should return correct defaults" do
     props=Rubyvis::Mark.defaults._properties.sort {|a,b| a.name.to_s<=>b.name.to_s}
-    props[1].name.should==:data
-    props[1].value.should be_instance_of Proc
-    props[3].name.should==:visible
-    props[0].name.should==:antialias
-    props[2].name.should==:events
+    expect(props[1].name).to eq(:data)
+    expect(props[1].value).to be_instance_of Proc
+    expect(props[3].name).to eq(:visible)
+    expect(props[0].name).to eq(:antialias)
+    expect(props[2].name).to eq(:events)
   end
   it "should have 'mark' as type" do
     m=Rubyvis::Mark.new
-    m.type.should eql "mark"
+    expect(m.type).to eql "mark"
   end
   
 end
\ No newline at end of file
