@@ -2,7 +2,7 @@ require File.expand_path(File.dirname(__FILE__)+"/spec_helper.rb")
 describe "Rubyvis Readme" do
   it "should work with RBP API" do
     vis=nil
-    lambda {
+    expect {
     vis = Rubyvis::Panel.new do 
       width 150
       height 150
@@ -15,12 +15,12 @@ describe "Rubyvis Readme" do
       end
     end
     
-    vis.render}.should_not raise_exception
-    vis.to_svg.size.should>0
+    vis.render}.not_to raise_exception
+    expect(vis.to_svg.size).to be > 0
   end
   it "should work with Protovis API" do
     vis=nil
-    lambda {
+    expect {
     vis = Rubyvis::Panel.new.width(150).height(150);
     
     vis.add(pv.Bar).
@@ -31,8 +31,8 @@ describe "Rubyvis Readme" do
       left(lambda {self.index * 25});
     
     vis.render
-    }.should_not raise_exception
-    vis.to_svg.size.should>0
+    }.not_to raise_exception
+    expect(vis.to_svg.size).to be > 0
   end
   
 end
