@@ -2,7 +2,7 @@ require File.expand_path(File.dirname(__FILE__)+"/spec_helper.rb")
 describe Rubyvis::Scale do
   it "should return a correct numeric interpolator" do
     i=Rubyvis::Scale.interpolator(0,20)
-    i[10].should==200
-    i[20].should==400
+    expect(i[10]).to eq(200)
+    expect(i[20]).to eq(400)
   end
 end
\ No newline at end of file
